@@ -17,6 +17,8 @@
 import datetime
 import logging
 import uuid
+from collections import defaultdict
+
 from math import ceil, floor
 
 from bitstring import BitStream
@@ -361,7 +363,7 @@ builtinTypes = {
 
 @FITypes.register(type_id=7)
 class FieldFI:
-	def init(self, format_type, base="DEC", bitmask=0, size=None, size_len=None, parse_with=None, **kw):
+	def init(self, format_type, base="DEC", bitmask=0, size=None, size_len=None, parse_with=None, value=None, **kw):
 		self.format_type = format_type
 		self.base = base
 		self.bitmask = bitmask
@@ -369,6 +371,7 @@ class FieldFI:
 		self.size_expr = deserialize_expr(size) if size else None
 		self.size_len_expr = deserialize_expr(size_len) if size_len else None
 		self.parse_with = parse_with
+		self.value_expr = deserialize_expr(value) if value else None
 
 	def _to_text(self, indent, refs, all_params):
 		return  self.format_type+""+params_to_text(indent, refs, all_params, ignore=['children', 'def_name', 'format_type'])
@@ -404,6 +407,9 @@ class FieldFI:
 		if magic is not None and value != magic:
 			raise invalid(context, "found magic value %r doesn't match spec %r" % (value, magic))
 
+		if self.value_expr:
+			value = self.value_expr.evaluate(context)
+
 		context.consume_bytes(n)
 		return context.pack_value(value)
 
@@ -460,13 +466,25 @@ class BitStructFI:
 			raw_data = raw_data[::-1]
 			le = True
 		stream = BitStream(raw_data)
+		bitsize = self.size * 8
+		bitpos = 0
 		pos = context.buf_offset * 8
+		multifields = defaultdict(dict)
 		for key, len in self.children:
 			if not le: context.buf_offset = floor(pos / 8)
-			context.push(desc=context.stack[-1].desc, id=key)
-			o[key] = context.pack_value(stream.read(len).uint)
+			field = stream.read(len)
+			context.push(desc={'print': ("."*bitpos) + field.bin + ("."*(bitsize-bitpos-len)) + "  " + key + " = " + str(field.uint)}, id=key)
+			o[key] = context.pack_value(field.uint)
 			context.pop()
+			if "__" in key:
+				multikey, pos = key.split("__")
+				if pos == "hi": pos = "0"
+				if pos == "lo": pos = "1"
+				multifields[multikey][pos] = (len, field.uint)
 			pos += len
+			bitpos += len
+		#for k, v in multifields.items():
+
 		context.buf_offset = ceil(pos / 8)
 		return context.pack_value(o)
 
